summaryrefslogtreecommitdiff
path: root/pkgs/development/python-modules/pyarrow/default.nix
diff options
context:
space:
mode:
authorRobin Gloster <mail@glob.in>2021-05-24 09:55:24 -0500
committerRobin Gloster <mail@glob.in>2021-05-24 09:55:24 -0500
commit4bc5fbef9d159e143fb7e2c3231932e6e76f667c (patch)
treee2198f5c552e0667d838b8ec764ddb3a4d8f6dec /pkgs/development/python-modules/pyarrow/default.nix
parentjq: fix build with structured-attrs on darwin (diff)
parentMerge pull request #123802 from superherointj/package-virtmanager-bugfix (diff)
downloadnixpkgs-origin/structured-attrs.tar.gz
Merge remote-tracking branch 'upstream/master' into structured-attrsorigin/structured-attrs
Diffstat (limited to 'pkgs/development/python-modules/pyarrow/default.nix')
-rw-r--r--pkgs/development/python-modules/pyarrow/default.nix17
1 files changed, 11 insertions, 6 deletions
diff --git a/pkgs/development/python-modules/pyarrow/default.nix b/pkgs/development/python-modules/pyarrow/default.nix
index a38d5df50ddf..dabe85b90432 100644
--- a/pkgs/development/python-modules/pyarrow/default.nix
+++ b/pkgs/development/python-modules/pyarrow/default.nix
@@ -34,12 +34,17 @@ buildPythonPackage rec {
export PYARROW_PARALLEL=$NIX_BUILD_CORES
'';
- # Deselect a single test because pyarrow prints a 2-line error message where
- # only a single line is expected. The additional line of output comes from
- # the glog library which is an optional dependency of arrow-cpp that is
- # enabled in nixpkgs.
- # Upstream Issue: https://issues.apache.org/jira/browse/ARROW-11393
- pytestFlagsArray = [ "--deselect=pyarrow/tests/test_memory.py::test_env_var" ];
+ pytestFlagsArray = [
+ # Deselect a single test because pyarrow prints a 2-line error message where
+ # only a single line is expected. The additional line of output comes from
+ # the glog library which is an optional dependency of arrow-cpp that is
+ # enabled in nixpkgs.
+ # Upstream Issue: https://issues.apache.org/jira/browse/ARROW-11393
+ "--deselect=pyarrow/tests/test_memory.py::test_env_var"
+ # Deselect the parquet dataset write test because it erroneously fails to find the
+ # pyarrow._dataset module.
+ "--deselect=pyarrow/tests/parquet/test_dataset.py::test_write_to_dataset_filesystem"
+ ];
dontUseSetuptoolsCheck = true;
preCheck = ''